@@ -106,7 +106,8 @@ def _load_credentials():
         f.close()
         username, password = base64.decodestring( _credentials ).split( ':', 1 )
     except Exception, e:
-        print "Failed to load your credentials. This exception was raised: %s" % e
+#        raise Exception( "Couldn't load your credentials. This exception was raised: %s" % e )
+        pass
 
 def _store_credentials():
     global username, password
@@ -190,7 +191,7 @@ class _API:
         """
         if self.location is None:
             raise Exception( "This object doen't point to any resource on the server." )
-        headers, content = self._make_request( self.location, 'DELETE' )
+        headers, content = _make_request( self.location, 'DELETE' )
         if _version == 1:
             return True
         elif _version == 2:
